@@ -1,4 +1,10 @@
-from ..audio.spec_process import get_data
+'''
+Date: 2022-12-12 21:00:22
+LastEditors: mushan wwd137669793@gmail.com
+LastEditTime: 2023-01-06 23:42:03
+FilePath: /mushan/mushan/audio/plot.py
+'''
+from ..audio.spec_process import get_feature
 import librosa
 import numpy as np
 from pathlib import Path
@@ -6,7 +12,7 @@ from pathlib import Path
 def plot_detail_info_from_file(audio, pitc_scale=1, pitch_mel=True, durations=None, level='f'):
     import matplotlib.pylab as plt
     
-    naudio, spec, melspec, F0 = get_data(audio)
+    naudio, spec, melspec, F0, eng = get_feature(audio)
     
     fig, ax = plt.subplots(figsize=(20, 4))
     im = ax.imshow(melspec, aspect="auto", origin="lower",
@@ -33,7 +39,7 @@ def plot_mel_from_data(audio, pitc_scale=1, pitch_mel=True, durations=None, leve
     import matplotlib.pylab as plt
     
     if isinstance(audio,str) or isinstance(audio,Path):
-        _, _, melspec, _ = get_data(audio)
+        _, _, melspec, _, _ = get_feature(audio)
         
     fig, ax = plt.subplots(figsize=(20, 4))
     im = ax.imshow(melspec, aspect="auto", origin="lower",
